*{
    border-radius:8;
    color:#6c7c96;
}

#container {
background-color:#2c313c;
}

#left_menu_frame{
background-color:#1b1e23;
}

#title_bar_frame{
background-color:#343b48;
}

#status_bar_frame{
background-color:#343b48;
}

#content_frame{
background-color:#343b48;
}

#setting_frame {
background-color:#3c4454;
}

#left_column_frame {
background-color:#343b48;
}

/* 侧边菜单栏样式 */

#LeftMenu {
background-color: #005dfd;
}

#LeftMenu QPushButton {
background-color:#1b1e23;
height:40;
text-align:left;
padding-left:15;
padding-top:2;
padding-bottom:2;
color:#6b7884;
}

#LeftMenu QPushButton:hover{
background-color:#21252d;
}

#LeftMenu QPushButton:pressed{
background-color:#2c313c;
}

#LeftMenu QPushButton:checked{
background-color:#2c313c;
}

#LeftMenu QPushButton:focus{
border:none;
}


#LeftMenu #bottom{
border-top:1 solid #272c36;
border-radius: 0;
}

#LeftMenu #nav_menu {
border-top:1 solid #272c36;
border-radius: 0；
}

#LeftMenu #scrollArea,#scrollAreaWidgetContents_3{
background-color:#1b1e23;
border:none;
}

#LeftMenu #btn_toggle:checked{
background-color:#21252d;
}


/* 标题栏样式 */

#TitleBar #bg{
background-color:#343b48;
border-radius:8;
}

#TitleBar #logo {
border: 1px solid #3c4454;
padding-right:10px;
border-top:none;
border-bottom:none;
border-left:none;
margin-right:5px;
border-radius:0;
}

#TitleBar  #logo_title{
color:#77b3f1;
font-size:20px;
font-weight:bold;
}

#TitleBar  #lb_title{
font-size:14px;
color:#6c7c96;
}

#TitleBar  QToolButton{
background-color:#343b48;
border:none;
border-radius:4;
padding: 4;
}

#TitleBar QToolButton:hover,
#TitleBar QToolButton:checked{
background-color:#3c4454;
}


#TitleBar QToolButton:pressed{
background-color:#e2e9f7;
}

#TitleBar #tool{
border:1px solid #3c4454;
border-top:none;
border-bottom:none;
margin-right:5px;
border-radius:0;
}


#LeftColumn{
background-color:#343b48;
}

#LeftColumn #top{
background-color: #3c4454;
}

#leftColumn #icon{

}

#LeftColumn #title{
color:#6c7c96;
}

#LeftColumn QToolButton{
border:none;
padding:4;
background-color: #3c4454;
}

#LeftColumn #btn_close:hover{
background-color:#343b48;
}

#LeftColumn #btn_close:pressed{
background-color:#1b1e23;
}


/* 通用控件 */

QToolTip { 
color:#6b7884;
background-color: #1b1e23; 
border-left: 2px solid #4f9fee;
border-radius: 8px;
}

QGroupBox{
	border: 2px solid gray; 
    border-radius: 3px; 
    margin:10;
}

QGroupBox::title { 
    subcontrol-position: center top; /* position at the top left*/ 
	subcontrol-origin: border;
	margin-top:-20px;

}

/* Button */
QAbstractButton{
background-color:#1b1e23;
border:none;
border-radius:4;
padding: 4;
outline:none;
width:36;
height:36;
}

QAbstractButton:hover,
QAbstractButton:checked{
background-color:#21252d;
}


QAbstractButton:pressed{
background-color:#272c36;
}

QAbstractButton:disabled{
background-color: #272c36;
}

QAbstractButton:checked{
background-color:#568af2;
color:black;
}

QAbstractButton:focus{
border: 2px solid #568af2;
}

QAbstractButton[style~='success']:checked{
    background-color: #67c23a;
}
QAbstractButton[style~='warning']:checked{
    background-color: #e6a23c;
}
QAbstractButton[style~='danger']:checked{
    background-color: #f56c6c;
}
QAbstractButton[style~='info']:checked{
    background-color: #909399;
}

/* CheckBox */

QCheckBox::indicator{
    border:2px solid #6c7c96;
    border-radius: 2px;
    width:10px;
    height:10px;
    margin-left:8px;
}

QCheckBox::indicator:checked{
    border:2px solid black;
    image: url(:/icon/assets/svg/checkmark.svg);
}

QRadioButton::indicator{
    border:1px solid #6c7c96;
    background-color:#6c7c96;
    border-radius: 4px;
    width:10px;
    height:10px;
    margin-left:8px;
}

QRadioButton::indicator:checked{
    border:1px solid #fff;
    background-color:black;
}

/* TextEdit */
QPlainTextEdit,
QTextEdit,
QLineEdit{
    background-color: #1b1e23;
    padding:8px;
}

QPlainTextEdit:focus,
QTextEdit:focus,
QLineEdit:focus{
    border: 2px solid #568af2;
}

QPlainTextEdit:read-only,
QTextEdit:read-only,
QLineEdit:read-only{
    border:none;
}

/* ProgressBar */
QProgressBar{
    background-color: #1b1e23;
    text-align:center;
    font-weight: bold;
}

QProgressBar::chunk:horizontal{
    background-color: #4f9fee;
    border-radius: 8px;
    border-top-right-radius: 0;
    border-bottom-right-radius:0;
}
QProgressBar::chunk:vertical{
    background-color: #4f9fee;
    border-radius: 8px;
    border-top-left-radius: 0;
    border-top-right-radius:0;
}


/* ScrollBar */
QScrollBar:horizontal{
    background-color: #2c313c;
    border-radius: 0;
    border:none;
    max-height: 8px;
}

QScrollBar::handle:horizontal{
    background-color:#568af2;
    border-radius:4px;
    min-width: 25px;
}

QScrollBar::add-page:horizontal{
    background-color:none;
}
QScrollBar::sub-page:horizontal{
    background-color:none;
}

QScrollBar::add-line:horizontal{
    background-color:#272c36;
    border:none;
    width:0px;
    border-top-right-radius: 4px;
    border-bottom-right-radius: 4px;
    /* subcontrol-position:right; */
    subcontrol-origin:margin;
}
QScrollBar::sub-line:horizontal{
    background-color:#272c36;
    border:none;
    width:0px;
    border-top-right-radius: 4px;
    border-bottom-right-radius: 4px;
    /* subcontrol-position:right; */
    subcontrol-origin:margin;
}

/* Vertical */
QScrollBar:vertical{
    background-color: #2c313c;
    border-radius: 0;
    border:none;
    max-width: 8px;
}

QScrollBar::handle:vertical{
    background-color:#568af2;
    border-radius:4px;
    min-height: 25px;
}

QScrollBar::add-page:vertical{
    background-color:none;
}
QScrollBar::sub-page:vertical{
    background-color:none;
}

QScrollBar::add-line:vertical{
    background-color:#272c36;
    border:none;
    width:0px;
    border-top-right-radius: 4px;
    border-top-left-radius: 4px;
    /* subcontrol-position:right; */
    subcontrol-origin:margin;
}
QScrollBar::sub-line:vertical{
    background-color:#272c36;
    border:none;
    width:0px;
    border-top-right-radius: 4px;
    border-top-left-radius: 4px;
    /* subcontrol-position:right; */
    subcontrol-origin:margin;
}


/* Slider */

QSlider:horizontal{
    margin:8;
}

QSlider::groove:horizontal{
    background-color: #1b1e23;
    border-radius: 4px;
    margin:0px;
    height: 10px;
}
QSlider::groove:horizontal:hover{
    background-color: #21252d;
}

QSlider::handle:horizontal{
    border:none;
    height:16px;
    width:16px;
    margin: -3px;
    border-radius: 8px;
    background-color: #4f9fee;
}

QSlider:vertical{
    margin:8;
}

QSlider::groove:vertical{
    background-color: #1b1e23;
    border-radius: 4px;
    margin:0px;
    width: 10px;
}
QSlider::groove:vertical:hover{
    background-color: #21252d;
}

QSlider::handle:vertical{
    border:none;
    height:16px;
    width:16px;
    margin: -3px;
    border-radius: 8px;
    background-color: #4f9fee;
}


/* ComboBox */

QComboBox{
    background-color: #1b1e23;
    padding:8px;
    selection-background-color:transparent;
}

QComboBox:disabled{
    background-color: #272c36;
}

QComboBox::drop-down{
    border-top-right-radius: 8px;
    border-bottom-right-radius: 8px;
    subcontrol-origin:padding;
    subcontrol-position:center right;
    background-color:#1b1e23;
    width:10px;
    padding:10px;
}

QComboBox::drop-down:disabled{
    background-color: #272c36;
}

QComboBox::drop-down:hover{
    background-color:black;
}

QComboBox::down-arrow{
    image:url(:/icon_w/assets/svg_white/circle-down.svg);
    width: 18px;
    height:18px;
}


/* TabWidget */
QTabWidget::pane { /* The tab widget frame */
    border-top: 2px solid #1b1e23;
    background-color:#1b1e23;
    border-radius: 8px;
    border-top-left-radius:0px;
}

QTabWidget::tab-bar {
    left: 0px; /* move to the right by 5px */
}

/* Style the tab using the tab sub-control. Note that
    it reads QTabBar _not_ QTabWidget */
QTabBar::tab {
    /* background: #1b1e23;
    border-bottom-color: #1b1e23;  */
    background:#2c313c;
    border-top-left-radius: 8px;
    border-top-right-radius: 8px;
    min-width: 8ex;
    padding: 8px;
}

QTabBar::tab:selected, QTabBar::tab:hover {
    background: #1b1e23;
    /* color:black; */
}

QTabBar::tab:!selected {
    margin-top: 2px; /* make non-selected tabs look smaller */
}


QScrollArea{
    background-color: transparent;
}


QScrollArea #scrollAreaWidgetContents *{
    margin-right:5px;
}



#Notification QToolButton{
    padding-left:20px;
    padding-right:20px;
    color:black;
}

QSplitter::handle{
    background-color: #2c313c;
    margin-top:5px;
    margin-bottom: 5px;
}


QTableWidget, QTableView{
	background-color:#343b48;
	/* padding:5px; */
gridline-color:#2c313c;
}

QTableWidget::item,
QTableView::item{
border-color:none;
padding-left:5px;
padding-right:5px;
gridline-color:rgb(44, 49, 60);
border-bottom: 1px solid #3c4454;
}

QTableWidget::item:selected,
QTableView::item:selected{
	background-color: #568af2;
}

QHeaderView::section{
	background-color: rgb(33, 37, 43);
	max-width: 30px;
	border: 1px solid rgb(44, 49, 58);
	border-style: none;
    border-bottom: 1px solid rgb(44, 49, 60);
    border-right: 1px solid rgb(44, 49, 60);
}

QTableWidget::horizontalHeader,
QTableView::horizontalHeader {
	background-color: rgb(33, 37, 43);
}

QTableWidget QTableCornerButton::section,
QTableView QTableCornerButton::section
 {
    border: none;
	background-color: rgb(33, 37, 43);
	padding: 3px;
    border-top-left-radius: 8px;
}

QHeaderView::section:horizontal
{
    border: none;
	background-color: rgb(33, 37, 43);
	padding: 3px;
}

QHeaderView::section:vertical
{
    border: none;
	background-color: rgb(33, 37, 43);
	padding-left: 5px;
    padding-right: 5px;
    border-bottom: 1px solid #3c4454;
}



QHeaderView {
    background-color: #21252b;
}

QHeaderView::section:horizontal:first
{

	background-color: rgb(33, 37, 43);
	padding: 3px;
border-top-left-radius: 8px;
}

QHeaderView::section:horizontal:last
{

	background-color: rgb(33, 37, 43);
	padding: 3px;
border-top-right-radius: 8px;
}

QTableWidget QLineEdit,
QTableView QLineEdit{
	padding:2px;
background-color:#568af2;
color:black;
}


/* profiler */

Monitor QFrame {
background-color: #1b1e23;
}


Logcat #container {
    background-color: #343b48;
}
